@@ -1,9 +1,10 @@
-#' Split uncontrained model parameters by fine-scale HMMs
-#' @param thetaUncon Unconstrained model parameters in vector form
-#' @param controls A list of controls
-#' @return Unconstrained fine-scale model parameters for each fine-scale HMM in list form
+#' Splits uncontrained model parameters \code{thetaUncon} by fine-scale HMMs.
+#' @param thetaUncon Unconstrained model parameters in vector form.
+#' @param controls A list of controls.
+#' @return List of unconstrained fine-scale model parameters for each fine-scale HMM.
+
 thetaUncon2thetaUnconSplit = function(thetaUncon,controls){
-  if(controls[["model"]]!="HHMM") stop("Function only for HHMMs")
+  if(controls[["model"]]!="HHMM") stop("function only for HHMMs")
   M = controls[["states"]][1] 
   N = controls[["states"]][2] 
   thetaUnconSplit = list()
